@@ -344,16 +344,9 @@ totem_properties_view_finalize (GObject *object)
 
 	props = TOTEM_PROPERTIES_VIEW (object);
 
-	if (props->priv != NULL)
-	{
-		if (props->priv->disco != NULL) {
-			g_object_unref (G_OBJECT (props->priv->disco));
-			props->priv->disco = NULL;
-		}
-		if (props->priv->label != NULL) {
-			g_object_unref (G_OBJECT (props->priv->label));
-			props->priv->label = NULL;
-		}
+	if (props->priv != NULL) {
+		g_clear_object (&props->priv->disco);
+		g_clear_object (&props->priv->label);
 		g_free (props->priv);
 	}
 	props->priv = NULL;
@@ -361,20 +354,7 @@ totem_properties_view_finalize (GObject *object)
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-GtkWidget *
-totem_properties_view_new (const char *location, GtkWidget *label)
-{
-	TotemPropertiesView *self;
-
-	self = g_object_new (TOTEM_TYPE_PROPERTIES_VIEW, NULL);
-	g_object_ref (label);
-	self->priv->label = label;
-	totem_properties_view_set_location (self, location);
-
-	return GTK_WIDGET (self);
-}
-
-void
+static void
 totem_properties_view_set_location (TotemPropertiesView *props,
 				    const char          *location)
 {
@@ -395,3 +375,15 @@ totem_properties_view_set_location (TotemPropertiesView *props,
 	}
 }
 
+GtkWidget *
+totem_properties_view_new (const char *location, GtkWidget *label)
+{
+	TotemPropertiesView *self;
+
+	self = g_object_new (TOTEM_TYPE_PROPERTIES_VIEW, NULL);
+	g_object_ref (label);
+	self->priv->label = label;
+	totem_properties_view_set_location (self, location);
+
+	return GTK_WIDGET (self);
+}
